#
# spec file for package perl-Audio-FLAC-Header
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Audio-FLAC-Header
Name:           perl-Audio-FLAC-Header
Version:        2.400.0
Release:        1699.6.pm.5
# 2.4 -> normalize -> 2.400.0
%define cpan_version 2.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Interface to FLAC header metadata
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DANIEL/%{cpan_name}-%{cpan_version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Audio::FLAC::Header) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module returns a hash containing basic information about a FLAC file,
a representation of the embedded cue sheet if one exists, as well as tag
information contained in the FLAC file's Vorbis tags. There is no complete
list of tag keys for Vorbis tags, as they can be defined by the user; the
basic set of tags used for FLAC files include:

	ALBUM
	ARTIST
	TITLE
	DATE
	GENRE
	TRACKNUMBER
	COMMENT

The information returned by Audio::FLAC::info is keyed by:

	MINIMUMBLOCKSIZE
	MAXIMUMBLOCKSIZE
	MINIMUMFRAMESIZE
	MAXIMUMFRAMESIZE
	TOTALSAMPLES
	SAMPLERATE
	NUMCHANNELS
	BITSPERSAMPLE
	MD5CHECKSUM

Information stored in the main hash that relates to the file itself or is
calculated from some of the information fields is keyed by:

	trackLengthMinutes      : minutes field of track length
	trackLengthSeconds      : seconds field of track length
	trackLengthFrames       : frames field of track length (base 75)
	trackTotalLengthSeconds : total length of track in fractional seconds
	bitRate                 : average bits per second of file
	fileSize                : file size, in bytes

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README TODO

%changelog
* Mon Oct  9 2017 olaf@aepfle.de
- Require Module::Install for perl 5.26
* Fri Mar 18 2011 pascal.bleser@opensuse.org
- initial version (2.4)
